@@ -20,19 +20,19 @@
 
 # Python translation from wrapLabel.{cc|h} by Gian Mario Tagliaretti
 
-import gtk
-import pango
+from gi.repository import Gtk
+from gi.repository import Pango
 
 
-class WrapLabel(gtk.Label):
+class WrapLabel(Gtk.Label):
     __gtype_name__ = 'WrapLabel'
 
     def __init__(self, text=None):
-        gtk.Label.__init__(self)
+        Gtk.Label.__init__(self)
 
         self.__wrap_width = 0
         self.layout = self.get_layout()
-        self.layout.set_wrap(pango.WRAP_WORD_CHAR)
+        self.layout.set_wrap(Pango.WrapMode.WORD_CHAR)
 
         if text is not None:
             self.set_text(text)
@@ -46,22 +46,22 @@ class WrapLabel(gtk.Label):
         requisition.height = height
 
     def do_size_allocate(self, allocation):
-        gtk.Label.do_size_allocate(self, allocation)
+        Gtk.Label.do_size_allocate(self, allocation)
         self.__set_wrap_width(allocation.width)
 
     def set_text(self, text):
-        gtk.Label.set_text(self, text)
+        Gtk.Label.set_text(self, text)
         self.__set_wrap_width(self.__wrap_width)
 
     def set_markup(self, text):
-        gtk.Label.set_markup(self, text)
+        Gtk.Label.set_markup(self, text)
         self.__set_wrap_width(self.__wrap_width)
 
     def __set_wrap_width(self, width):
         if width == 0:
             return
         layout = self.get_layout()
-        layout.set_width(width * pango.SCALE)
+        layout.set_width(width * Pango.SCALE)
         if self.__wrap_width != width:
             self.__wrap_width = width
             self.queue_resize()
