@@ -32,7 +32,7 @@ import shutil
 import subprocess
 import tempfile
 
-from gettext import gettext as _, ngettext
+from meld.conf import _, ngettext
 
 from . import _vc
 
@@ -205,6 +205,10 @@ class Vc(_vc.CachedVc):
             command = [self.CMD, 'checkout', 'HEAD']
             runner(command, missing, refresh=True, working_dir=self.root)
 
+    def resolve(self, runner, files):
+        command = [self.CMD, 'add']
+        runner(command, files, refresh=True, working_dir=self.root)
+
     def get_path_for_conflict(self, path, conflict):
         if not path.startswith(self.root + os.path.sep):
             raise _vc.InvalidVCPath(self, path, "Path not in repository")
@@ -301,9 +305,10 @@ class Vc(_vc.CachedVc):
             try:
                 entries = self._get_modified_files(path)
 
-                # Identify ignored files
+                # Identify ignored files and folders
                 proc = _vc.popen([self.CMD, "ls-files", "--others",
-                                  "--ignored", "--exclude-standard", path],
+                                  "--ignored", "--exclude-standard",
+                                  "--directory", path],
                                  cwd=self.location)
                 ignored_entries = proc.read().split("\n")[:-1]
 
@@ -325,6 +330,7 @@ class Vc(_vc.CachedVc):
             # 'entries' list, and tree_state['path'] will still contain stale
             # data.  When this corner case occurs we force tree_state['path']
             # to STATE_NORMAL.
+            path = os.path.abspath(path)
             tree_state[path] = _vc.STATE_NORMAL
         else:
             # There are 1 or more modified files, parse their state
@@ -335,6 +341,7 @@ class Vc(_vc.CachedVc):
                     # Git returns unix-style paths on Windows
                     name = os.path.normpath(name.strip())
                 path = os.path.join(self.root, name.strip())
+                path = os.path.abspath(path)
                 state = self.state_map.get(statekey.strip(), _vc.STATE_NONE)
                 tree_state[path] = state
                 if old_mode != new_mode:
@@ -344,10 +351,12 @@ class Vc(_vc.CachedVc):
 
             for entry in ignored_entries:
                 path = os.path.join(self.location, entry.strip())
+                path = os.path.abspath(path)
                 tree_state[path] = _vc.STATE_IGNORED
 
             for entry in unversioned_entries:
                 path = os.path.join(self.location, entry.strip())
+                path = os.path.abspath(path)
                 tree_state[path] = _vc.STATE_NONE
 
     def _lookup_tree_cache(self, rootdir):
@@ -371,8 +380,8 @@ class Vc(_vc.CachedVc):
             meta = self._tree_meta_cache.get(path, "")
             retfiles.append(_vc.File(path, name, state, options=meta))
         for name, path in dirs:
-            # git does not operate on dirs, just files
-            retdirs.append(_vc.Dir(path, name, _vc.STATE_NORMAL))
+            state = tree.get(path, _vc.STATE_NORMAL)
+            retdirs.append(_vc.Dir(path, name, state))
         for path, state in tree.items():
             # removed files are not in the filesystem, so must be added here
             if state in (_vc.STATE_REMOVED, _vc.STATE_MISSING):
